@@ -10,12 +10,11 @@ use Scalar::Util qw(blessed);
 our $BASE_EXC_CLASS;
 BEGIN { $BASE_EXC_CLASS ||= 'Exception::Class::Base'; }
 
-our $VERSION = '1.29';
+our $VERSION = '1.30';
 
 our %CLASSES;
 
-sub import
-{
+sub import {
     my $class = shift;
 
     local $Exception::Class::Caller = caller();
@@ -23,19 +22,20 @@ sub import
     my %c;
 
     my %needs_parent;
-    while (my $subclass = shift)
-    {
+    while ( my $subclass = shift ) {
         my $def = ref $_[0] ? shift : {};
-        $def->{isa} = $def->{isa} ? ( ref $def->{isa} ? $def->{isa} : [$def->{isa}] ) : [];
+        $def->{isa}
+            = $def->{isa}
+            ? ( ref $def->{isa} ? $def->{isa} : [ $def->{isa} ] )
+            : [];
 
         $c{$subclass} = $def;
     }
 
     # We need to sort by length because if we check for keys in the
     # Foo::Bar:: stash, this creates a "Bar::" key in the Foo:: stash!
- MAKE_CLASSES:
-    foreach my $subclass ( sort { length $a <=> length $b } keys %c )
-    {
+MAKE_CLASSES:
+    foreach my $subclass ( sort { length $a <=> length $b } keys %c ) {
         my $def = $c{$subclass};
 
         # We already made this one.
@@ -43,37 +43,37 @@ sub import
 
         {
             no strict 'refs';
-            foreach my $parent (@{ $def->{isa} })
-            {
-                unless ( keys %{"$parent\::"} )
-                {
-                    $needs_parent{$subclass} = { parents => $def->{isa},
-                                                 def => $def };
+            foreach my $parent ( @{ $def->{isa} } ) {
+                unless ( keys %{"$parent\::"} ) {
+                    $needs_parent{$subclass} = {
+                        parents => $def->{isa},
+                        def     => $def
+                    };
                     next MAKE_CLASSES;
                 }
             }
         }
 
-        $class->_make_subclass( subclass => $subclass,
-                                def => $def || {},
-                              );
+        $class->_make_subclass(
+            subclass => $subclass,
+            def      => $def || {},
+        );
     }
 
-    foreach my $subclass (keys %needs_parent)
-    {
+    foreach my $subclass ( keys %needs_parent ) {
+
         # This will be used to spot circular references.
         my %seen;
         $class->_make_parents( \%needs_parent, $subclass, \%seen );
     }
 }
 
-sub _make_parents
-{
-    my $class = shift;
-    my $needs = shift;
+sub _make_parents {
+    my $class    = shift;
+    my $needs    = shift;
     my $subclass = shift;
-    my $seen = shift;
-    my $child = shift; # Just for error messages.
+    my $seen     = shift;
+    my $child    = shift;    # Just for error messages.
 
     no strict 'refs';
 
@@ -83,11 +83,14 @@ sub _make_parents
     # If neither of these is true then the _only_ place it is
     # mentioned is in the 'isa' param for some other class, which is
     # not a good enough reason to make a new class.
-    die "Class $subclass appears to be a typo as it is only specified in the 'isa' param for $child\n"
-        unless exists $needs->{$subclass} || $CLASSES{$subclass} || keys %{"$subclass\::"};
+    die
+        "Class $subclass appears to be a typo as it is only specified in the 'isa' param for $child\n"
+        unless exists $needs->{$subclass}
+            || $CLASSES{$subclass}
+            || keys %{"$subclass\::"};
+
+    foreach my $c ( @{ $needs->{$subclass}{parents} } ) {
 
-    foreach my $c ( @{ $needs->{$subclass}{parents} } )
-    {
         # It's been made
         next if $CLASSES{$c} || keys %{"$c\::"};
 
@@ -101,21 +104,21 @@ sub _make_parents
 
     return if $CLASSES{$subclass} || keys %{"$subclass\::"};
 
-    $class->_make_subclass( subclass => $subclass,
-                            def => $needs->{$subclass}{def} );
+    $class->_make_subclass(
+        subclass => $subclass,
+        def      => $needs->{$subclass}{def}
+    );
 }
 
-sub _make_subclass
-{
+sub _make_subclass {
     my $class = shift;
-    my %p = @_;
+    my %p     = @_;
 
     my $subclass = $p{subclass};
-    my $def = $p{def};
+    my $def      = $p{def};
 
     my $isa;
-    if ($def->{isa})
-    {
+    if ( $def->{isa} ) {
         $isa = ref $def->{isa} ? join ' ', @{ $def->{isa} } : $def->{isa};
     }
     $isa ||= $BASE_EXC_CLASS;
@@ -133,10 +136,8 @@ our \$$version_name = '1.1';
 
 EOPERL
 
-
-    if ($def->{description})
-    {
-        (my $desc = $def->{description}) =~ s/([\\\'])/\\$1/g;
+    if ( $def->{description} ) {
+        ( my $desc = $def->{description} ) =~ s/([\\\'])/\\$1/g;
         $code .= <<"EOPERL";
 sub description
 {
@@ -146,27 +147,33 @@ EOPERL
     }
 
     my @fields;
-    if ( my $fields = $def->{fields} )
-    {
-        @fields = UNIVERSAL::isa($fields, 'ARRAY') ? @$fields : $fields;
+    if ( my $fields = $def->{fields} ) {
+        @fields = UNIVERSAL::isa( $fields, 'ARRAY' ) ? @$fields : $fields;
 
-        $code .=
-            "sub Fields { return (\$_[0]->SUPER::Fields, " .
-            join(", ", map { "'$_'" } @fields) . ") }\n\n";
+        $code
+            .= "sub Fields { return (\$_[0]->SUPER::Fields, "
+            . join( ", ", map {"'$_'"} @fields )
+            . ") }\n\n";
 
-        foreach my $field (@fields)
-        {
-            $code .= sprintf("sub %s { \$_[0]->{%s} }\n", $field, $field);
+        foreach my $field (@fields) {
+            $code .= sprintf( "sub %s { \$_[0]->{%s} }\n", $field, $field );
         }
     }
 
-    if ( my $alias = $def->{alias} )
-    {
+    if ( my $alias = $def->{alias} ) {
         die "Cannot make alias without caller"
             unless defined $Exception::Class::Caller;
 
         no strict 'refs';
-        *{"$Exception::Class::Caller\::$alias"} = sub { $subclass->throw(@_) };
+        *{"$Exception::Class::Caller\::$alias"}
+            = sub { $subclass->throw(@_) };
+    }
+
+    if ( my $defaults = $def->{defaults} ) {
+        $code
+            .= "sub _defaults { return shift->SUPER::_defaults, our \%_DEFAULTS }\n";
+        no strict 'refs';
+        *{"$subclass\::_DEFAULTS"} = {%$defaults};
     }
 
     eval $code;
@@ -176,8 +183,7 @@ EOPERL
     $CLASSES{$subclass} = 1;
 }
 
-sub caught
-{
+sub caught {
     my $e = $@;
 
     return $e unless $_[1];
@@ -198,43 +204,41 @@ Exception::Class - A module that allows you to declare real exception classes in
 
 =head1 SYNOPSIS
 
-  use Exception::Class
-      ( 'MyException',
+  use Exception::Class (
+      'MyException',
 
-        'AnotherException' =>
-        { isa => 'MyException' },
+      'AnotherException' => { isa => 'MyException' },
 
-        'YetAnotherException' =>
-        { isa => 'AnotherException',
-          description => 'These exceptions are related to IPC' },
+      'YetAnotherException' => {
+          isa         => 'AnotherException',
+          description => 'These exceptions are related to IPC'
+      },
 
-        'ExceptionWithFields' =>
-        { isa => 'YetAnotherException',
+      'ExceptionWithFields' => {
+          isa    => 'YetAnotherException',
           fields => [ 'grandiosity', 'quixotic' ],
-          alias => 'throw_fields',
-        },
-      );
+          alias  => 'throw_fields',
+      },
+  );
 
   # try
   eval { MyException->throw( error => 'I feel funny.' ) };
 
   my $e;
-  # catch
-  if ( $e = Exception::Class->caught('MyException') )
-  {
-     warn $e->error, "\n", $e->trace->as_string, "\n";
-     warn join ' ',  $e->euid, $e->egid, $e->uid, $e->gid, $e->pid, $e->time;
 
-     exit;
+  # catch
+  if ( $e = Exception::Class->caught('MyException') ) {
+      warn $e->error, "\n", $e->trace->as_string, "\n";
+      warn join ' ', $e->euid, $e->egid, $e->uid, $e->gid, $e->pid, $e->time;
+
+      exit;
   }
-  elsif ( $e = Exception::Class->caught('ExceptionWithFields') )
-  {
-     $e->quixotic ? do_something_wacky() : do_something_sane();
+  elsif ( $e = Exception::Class->caught('ExceptionWithFields') ) {
+      $e->quixotic ? do_something_wacky() : do_something_sane();
   }
-  else
-  {
-     $e = Exception::Class->caught();
-     ref $e ? $e->rethrow : die $e;
+  else {
+      $e = Exception::Class->caught();
+      ref $e ? $e->rethrow : die $e;
   }
 
   # use an alias - without parens subroutine name is checked at
@@ -293,7 +297,7 @@ To change the default exception class you will need to change the
 value of C<$Exception::Class::BASE_EXC_CLASS> I<before> calling
 C<import()>.  To do this simply do something like this:
 
-BEGIN { $Exception::Class::BASE_EXC_CLASS = 'SomeExceptionClass'; }
+  BEGIN { $Exception::Class::BASE_EXC_CLASS = 'SomeExceptionClass'; }
 
 If anyone can come up with a more elegant way to do this please let me
 know.
@@ -353,13 +357,12 @@ Foo and never declare Foo.
 C<Exception::Class> provides some syntactic sugar for catching
 exceptions in a safe manner:
 
- eval { ... }
+  eval {...};
 
- if ( my $e = Exception::Class->caught('My::Error') )
- {
-     cleanup();
-     do_something_with_exception($e);
- }
+  if ( my $e = Exception::Class->caught('My::Error') ) {
+      cleanup();
+      do_something_with_exception($e);
+  }
 
 The C<caught()> method takes a class name and returns an exception
 object if the last thrown exception is of the given class, or a
@@ -374,11 +377,10 @@ C<do_something_with_exception()>.
 
 Exception objects also provide a caught method so you can write:
 
- if ( my $e = My::Error->caught() )
- {
-     cleanup();
-     do_something_with_exception($e);
- }
+  if ( my $e = My::Error->caught() ) {
+      cleanup();
+      do_something_with_exception($e);
+  }
 
 =head2 Uncatchable Exceptions
 
@@ -407,20 +409,24 @@ This might look something like this:
 
   package Foo::Bar::Exceptions;
 
-  use Exception::Class ( Foo::Bar::Exception::Senses =>
-                        { description => 'sense-related exception' },
+  use Exception::Class (
+      Foo::Bar::Exception::Senses =>
+          { description => 'sense-related exception' },
 
-                         Foo::Bar::Exception::Smell =>
-                         { isa => 'Foo::Bar::Exception::Senses',
-                           fields => 'odor',
-                           description => 'stinky!' },
+      Foo::Bar::Exception::Smell => {
+          isa         => 'Foo::Bar::Exception::Senses',
+          fields      => 'odor',
+          description => 'stinky!'
+      },
 
-                         Foo::Bar::Exception::Taste =>
-                         { isa => 'Foo::Bar::Exception::Senses',
-                           fields => [ 'taste', 'bitterness' ],
-                           description => 'like, gag me with a spoon!' },
+      Foo::Bar::Exception::Taste => {
+          isa         => 'Foo::Bar::Exception::Senses',
+          fields      => [ 'taste', 'bitterness' ],
+          description => 'like, gag me with a spoon!'
+      },
 
-                         ... );
+      ...
+  );
 
 You may want to create a real module to subclass
 L<Exception::Class::Base> as well, particularly if you want your
